@@ -1,4 +1,17 @@
-"""Main module."""
+"""
+This module enables connecting to AWS and extracting metadata in pandas dataframes.
+
+**Installing from PyPI:** *pip install -U awsdf*
+
+**USAGE:**
+
+    import awsdf
+
+    aws_account = awsdf.Account(profile_name="<PROFILE_NAME>")
+
+    glue_databases_df = aws_account.glue_get_databases()
+
+"""
 from datetime import timedelta, datetime
 from awswrangler import exceptions
 import boto3
@@ -39,6 +52,10 @@ error_df = pd.DataFrame(columns=["Error"], data=[[-1]])
 
 
 class Account(object):
+    """
+    Instantiate class object for connecting to AWS and retriving metadata from AWS
+    """
+
     def __init__(
         self,
         aws_access_key_id=None,
@@ -49,10 +66,18 @@ class Account(object):
     ):
         """
         Provide access keys OR Profile name to connect to AWS account. Keys take preceedence
-        Parameters:
-            aws_access_key_id (string) -- AWS access key ID
-            aws_secret_access_key (string) -- AWS secret access key
-            aws_session_token (string) -- AWS temporary session token
+
+        **Parameters:**
+
+            *aws_access_key_id (string) -- AWS access key ID*
+
+            *aws_secret_access_key (string) -- AWS secret access key*
+
+            *aws_session_token (string) -- AWS temporary session token*
+
+            *region_name (string) -- AWS region*
+
+            *profile_name (string) -- AWS profile name*
         """
         try:
             self._session = boto3.Session(
@@ -103,7 +128,13 @@ class Account(object):
             logger.error(error)
             exit(0)
 
-    def glue_get_jobs(self):
+    def glue_get_jobs(self) -> pd.DataFrame:
+        """
+        Get AWS Glue jobs
+
+        Returns:
+            dataframe
+        """
         glue_job_df_columns = ["Name", "CreatedOn", "LastModifiedOn"]
 
         # initialize Glue client
@@ -124,7 +155,20 @@ class Account(object):
 
         return jobs_df
 
-    def glue_get_job_history(self, job_name, no_of_runs=1):
+    def glue_get_job_history(self, job_name, no_of_runs=1) -> pd.DataFrame:
+        """
+        Retrieve glue job history
+
+        Arguments:
+            job_name -- Name of job to retrive history
+
+        Keyword Arguments:
+            no_of_runs -- No of runs to retrive in descending order (default: {1})
+
+        Returns:
+            dataframe
+        """
+
         glue_run_df_columns = [
             "Id",
             "JobName",
@@ -230,13 +274,28 @@ class Account(object):
 
         return final_df
 
-    def glue_get_databases(self) -> DataFrame:
+    def glue_get_databases(self) -> pd.DataFrame:
+        """
+        Get AWS Glue jobs
+
+        Returns:
+            dataframe
+        """
         dbs = wr.catalog.get_databases(boto3_session=self.session)
         data = [(db["Name"]) for db in dbs]
         databases_df = pd.DataFrame(data, columns=["DBName"])
         return databases_df
 
-    def glue_get_tables(self, dbname=None):
+    def glue_get_tables(self, dbname=None) -> pd.DataFrame:
+        """
+        Get AWS Glue tables
+
+        Keyword Arguments:
+            dbname -- Database Name for which to retrive tables (default: {None})
+
+        Returns:
+            dataframe
+        """
         tables = wr.catalog.get_tables(database=dbname, boto3_session=self.session)
 
         data = [
@@ -342,13 +401,6 @@ class Account(object):
         database="qdl_temp",
         mode="overwrite",
     ):
-        """
-        create_athena_table
-
-        Arguments:
-            dataframe_to_upload
-        """
-
         try:
             session = self.session
             wr.s3.to_parquet(
